require "util"
require "config"

script.on_init(function()
	global.growing_saplings_record = {}
	global.seed_fall_record = {}
end)

script.on_configuration_changed(function(ConfigurationChangedData)
	
end)

script.on_event(defines.events.on_built_entity, function(event)
	if event.created_entity.name == "planted-sapling" then
		add_sapling_to_record(event.created_entity.position, event.tick, MAX_PROPERGATIONS, get_tree_name(event.created_entity.position))
	end
end)

script.on_event(defines.events.on_tick, function(event)
	local tick = event.tick
	if tick % TICKS_BETWEEN_UPDATES == 0 then
		update_saplings(tick)
	end
end)

script.on_event(defines.events.on_entity_died, function(event)
	if event.entity.name == "planted-sapling" then
		remove_sapling_from_record(event.entity.position)
	else
		if event.entity.type == "tree" then
			distribute_falling_seeds(event.entity.position, MAX_PROPERGATIONS, event.entity.name)
		end
	end
end)

script.on_event(defines.events.on_preplayer_mined_item, function(event)
	if event.entity.name == "planted-sapling" then
		remove_sapling_from_record(event.position)
	end
end)



function update_saplings(tick)
	local pos
	local cycles
	local name
	
	if #global.growing_saplings_record > 0 then
		if tick > global.growing_saplings_record[1].tick then 
			grow_tree(global.growing_saplings_record[1].position)
		end
	end

	if #global.seed_fall_record > 0 then
		if tick > global.seed_fall_record[1].tick then
			pos = global.seed_fall_record[1].position
			cycles = global.seed_fall_record[1].remaining
			name = global.seed_fall_record[1].name
			
			if name == nil then
				name = DEFAULT_TREE
			end
			
			if out_of_sight(pos) or SAPLINGS_SPROUT_NEXT_TO_PLAYER then
				if game.surfaces.nauvis.can_place_entity({name = "planted-sapling", position = pos}) then
					game.surfaces.nauvis.create_entity({name = "planted-sapling", position = pos})
					add_sapling_to_record(pos, tick, cycles, name)
				end
			else
				--printmsg("player too close")
				add_seed_to_record(pos.x, pos.y, cycles, name)
			end
			
			table.remove(global.seed_fall_record, 1)
			--printmsg(#global.seed_fall_record)
		end
	end
end


function add_sapling_to_record(pos, tick, cycles, name)
	local tile_name = game.surfaces.nauvis.get_tile(pos.x, pos.y).name
	local valid_tile = true
	
	--printmsg(tile_name)
	
	for index, dislike in pairs(TREES_DONT_GROW_ON) do
		if string.find(tile_name, dislike) ~= nil then
			valid_tile = false
		end
	end
	
	if valid_tile == true then 
		table.insert(global.growing_saplings_record, 
													{	
														position = {x = pos.x, y = pos.y}, 
														tick = tick + TICKS_TO_GROW,
														remaining = cycles,
														name = name
													})
	else
		game.surfaces.nauvis.find_entity("planted-sapling", {pos.x, pos.y}).destroy()
	end
end


function distribute_falling_seeds(pos, cycles, name)
	local tempx = 0
	local tempy = 0
	local seed_fall_roll = math.random(100)
	
	if seed_fall_roll < SEED_FALL_CHANCE then	
		tempx = math.floor(pos.x + (math.random(MAX_SEED_FALL_DISTANCE) * random_modifier())) + 0.5
		tempy = math.floor(pos.y + (math.random(MAX_SEED_FALL_DISTANCE) * random_modifier())) + 0.5
		
		add_seed_to_record(tempx, tempy, cycles, name)	
	end
end


function add_seed_to_record(posx, posy, cycles, name)
	--printmsg("Adding seed to record : "..posx..","..posy.." "..cycles)
	table.insert(global.seed_fall_record, 
				{
					position = {x = posx, y = posy},
					tick = game.tick + TICKS_TO_GERMINATE,
					remaining = cycles,
					name = name
				})
end


function remove_sapling_from_record(pos)
	if global.growing_saplings_record ~= nil and pos ~= nil then
		if pos.x ~= nil and pos.y ~= nil then
			if #global.growing_saplings_record > 0 then
				for index, sapling in pairs(global.growing_saplings_record) do	
					if sapling.position.x == pos.x and sapling.position.y == pos.y then
						table.remove(global.growing_saplings_record, index)
						return
					end
				end
			end
		end
	end
end


function grow_tree(pos)
	local cycles
	local tree
	sapling = game.surfaces.nauvis.find_entity("planted-sapling", {pos.x, pos.y})
	
	if sapling ~= nil then
		if global.growing_saplings_record[1].remaining ~= nil then
			cycles = global.growing_saplings_record[1].remaining - 1
		else
			cycles = 0
		end
		
		tree = global.growing_saplings_record[1].name
		if tree == nil then
			tree = DEFAULT_TREE
		end

		if cycles > 0 and math.random(100) < PROPERGATION_CHANCE then
			distribute_falling_seeds(pos, cycles, tree)
		end
		
		sapling.destroy()
		
		if game.surfaces.nauvis.can_place_entity({name = tree, position = pos}) then
			game.surfaces.nauvis.create_entity({name = tree, position = pos})	
		end
	end

	table.remove(global.growing_saplings_record, 1)
end


function random_modifier()
	local temp = math.random(100)%2
	
	if temp == 0 then
		temp = -1
	end
	
	return temp
end

function out_of_sight(tree)
	local player_x
	local player_y
	
	for index, player in pairs(game.players) do
		player_x = math.floor(player.position.x) + 0.5
		player_y = math.floor(player.position.y) + 0.5

		if math.abs(player_x - tree.x) < NO_SPROUT_ZONE_X then
			if math.abs(player_y - tree.y) < NO_SPROUT_ZONE_Y then
				return false
			end
		end
	end
	
	return true
end

function printmsg(msg)
	game.players[1].print(msg)
end

function get_tree_name(pos)
	local name = "none"
	local search_radius = 8
	local found_entities
	local temp
	
	while name == "none" do
		found_entities = game.surfaces.nauvis.find_entities_filtered({area={{pos.x-search_radius, pos.y-search_radius},{pos.x+search_radius, pos.y+search_radius}},type="tree"})
		
		if #found_entities > 0 then
			index = math.ceil(math.random(#found_entities))
			--printmsg(index)
			temp = found_entities[index].name
			if temp ~= "planted-sapling" then
				return temp
			end
			
			for index = 1, #found_entities do
				temp = found_entities[index].name
				if temp ~= "planted-sapling" then
					return temp
				end
			end
		end
		
		if search_radius < MAX_SEARCH_RADIUS then
			search_radius = search_radius *2
		else
			name = DEFAULT_TREE
		end
	end
	return name
end

