local dat = data.raw
-- full represents solid objects like walls and pipes; part blends with terrain slightly for semi-solids like belts; slight is for transitions like pipe-to-ground
-- this helps keep the alpha scheme consistent, aiding in navigation around objects from map view
local slight, part, full = 0.5, 0.8, 1.0

-- friendly turrets are bright green
dat["ammo-turret"]["gun-turret"].friendly_map_color = {r=0, g=1.0, b=.5, a = full}
dat["electric-turret"]["laser-turret"].friendly_map_color = {r=0, g=.7, b=.5, a = full}
dat["fluid-turret"]["flamethrower-turret"].friendly_map_color = {r=0, g=.5, b=.5, a = full}

-- boilers and furnaces are orange
dat.boiler.boiler.friendly_map_color = {r=1.0, g=.7, b=.3, a = full}
dat.furnace["stone-furnace"].friendly_map_color = {r=1.0, g=.5, b=.1, a = full}
dat.furnace["steel-furnace"].friendly_map_color = {r=1.0, g=.6, b=.2, a = full}
dat.furnace["electric-furnace"].friendly_map_color = {r=.9, g=.8, b=.1, a = full}

-- electric sources are light yellow
dat.generator["steam-engine"].friendly_map_color = {r=.9, g=.8, b=.4, a = full}
dat["solar-panel"]["solar-panel"].friendly_map_color = {r=.9, g=.9, b=.5, a = full}
dat.accumulator.accumulator.friendly_map_color = {r=.6, g=.6, b=.2, a = full}

-- electric poles are yellow-grey with part alpha, to help distinguish them from other grey things (which are all solid)
dat["electric-pole"]["small-electric-pole"].friendly_map_color = {r=.7, g=.7, b=.5, a = part}
dat["electric-pole"]["medium-electric-pole"].friendly_map_color = {r=.8, g=.8, b=.6, a = part}
dat["electric-pole"]["big-electric-pole"].friendly_map_color = {r=.9, g=.9, b=.7, a = part}
dat["electric-pole"].substation.friendly_map_color = {r=1.0, g=1.0, b=.8, a = full}
if dat["electric-pole"]["big-wooden-pole"] then dat["electric-pole"]["big-wooden-pole"].map_color = {r=.9, g=.8, b=.7, a = part} end

-- oil processing is dark purple
dat["assembling-machine"]["oil-refinery"].friendly_map_color = {r=.4, g=.2, b=.7, a = full}
dat["assembling-machine"]["chemical-plant"].friendly_map_color = {r=.5, g=.3, b=.7, a = full}
dat.pipe.pipe.friendly_map_color = {r=.6, g=.5, b=.6, a = full}					-- grey-purple and full , since it's impassible
for k,entity in pairs( dat["pipe-to-ground"] ) do entity.friendly_map_color = {r=.6, g=.5, b=.6, a = full} end
dat["pipe-to-ground"]["pipe-to-ground"].friendly_map_color.a = part
dat["storage-tank"]["storage-tank"].friendly_map_color = {r=.45, g=.3, b=.45, a = full}		-- slightly darker and purpler, to fit with oil processing
dat.pump["small-pump"].friendly_map_color = {r=.8, g=.4, b=.4, a = full}			-- grey-red
dat["mining-drill"].pumpjack.friendly_map_color = {r=.4, g=1.0, b=.3, a = full}		-- dark green

-- belts, splitters, and pipes are colored appropriately (with part alpha since they're not solid like walls)
local basic, fast, express = {r=.8, g=.8, b=.2, a=part}, {r=1.0, g=.4, b=.4, a=part}, {r=.3, g=.6, b=.9, a=part}		-- saves lots of time and work whenever I want to tweak the color scheme (and reduces memory usage slightly)
dat["transport-belt"]["transport-belt"].friendly_map_color = basic
dat["transport-belt"]["fast-transport-belt"].friendly_map_color = fast
dat["transport-belt"]["express-transport-belt"].friendly_map_color = express
dat.splitter["splitter"].friendly_map_color = basic
dat.splitter["fast-splitter"].friendly_map_color = fast
dat.splitter["express-splitter"].friendly_map_color = express
dat["underground-belt"]["underground-belt"].friendly_map_color = basic
dat["underground-belt"]["fast-underground-belt"].friendly_map_color = fast
dat["underground-belt"]["express-underground-belt"].friendly_map_color = express
dat["underground-belt"]["underground-belt"].friendly_map_color.a = slight
dat["underground-belt"]["fast-underground-belt"].friendly_map_color.a = slight
dat["underground-belt"]["express-underground-belt"].friendly_map_color.a = slight

-- so are the inserters
dat.inserter["burner-inserter"].friendly_map_color = {r=.5, g=.4, b=.35, a = full}
dat.inserter["inserter"].friendly_map_color = {r=.8, g=.7, b=.3, a = full}
dat.inserter["long-handed-inserter"].friendly_map_color = {r=.8, g=.3, b=.3, a = full}
dat.inserter["fast-inserter"].friendly_map_color = {r=.3, g=.3, b=.8, a = full}
dat.inserter["filter-inserter"].friendly_map_color = {r=.65, g=.3, b=.8, a = full}
dat.inserter["stack-inserter"].friendly_map_color = {r=.3, g=.7, b=.4, a = full}
dat.inserter["stack-filter-inserter"].friendly_map_color = {r=0.8, g=0.8, b=0.8, a = full}

-- and the assemblers
dat["assembling-machine"]["assembling-machine-1"].friendly_map_color = {r=.5, g=.5, b=.5, a = full}
dat["assembling-machine"]["assembling-machine-2"].friendly_map_color = {r=.3, g=.5, b=.8, a = full}
dat["assembling-machine"]["assembling-machine-3"].friendly_map_color = {r=.5, g=.7, b=.3, a = full}

-- and the combinators
dat["arithmetic-combinator"]["arithmetic-combinator"].friendly_map_color = {r=.7,g=.7, b=.7, alpha = part}
dat["constant-combinator"]["constant-combinator"].friendly_map_color = {r=.8, g=.6, b=.6, alpha = part}
dat["decider-combinator"]["decider-combinator"].friendly_map_color = {r=.9, g=.8, b=.4, alpha = part}

-- and the chests, which are also very bright with full alpha (for improved visibility)
dat.container["wooden-chest"].friendly_map_color = {r=.9, g=.8, b=.5, a = full}
dat.container["iron-chest"].friendly_map_color = {r=.7, g=.7, b=.5, a = full}
dat.container["steel-chest"].friendly_map_color = {r=1.0, g=1.0, b=.95, a = full}
dat["logistic-container"]["logistic-chest-active-provider"].friendly_map_color = {r=.8, g=.5, b=1.0, a = full}
dat["logistic-container"]["logistic-chest-passive-provider"].friendly_map_color = {r=1.0, g=.6, b=.6, a = full}
dat["logistic-container"]["logistic-chest-requester"].friendly_map_color = {r=.6, g=.6, b=1.0, a = full}
dat["logistic-container"]["logistic-chest-storage"].friendly_map_color = {r=1.0, g=1.0, b=.6, a = full}

-- resource colors are more gentle and natural
dat.resource["crude-oil"].map_color = {r=.25, g=.05, b=0, a = full}		-- oil isn't magenta, stop making my map ugly D:
dat.resource["coal"].map_color.a = part		-- reduce alpha of resource fields so they don't obscure quite so badly
dat.resource["iron-ore"].map_color.a = part		-- (note how only changing the alpha lets other mods change the color)
dat.resource["copper-ore"].map_color.a = part
dat.resource.stone.map_color = {r=.4, g=.35, b=.25, a = full}		-- lighter and browner, but full alpha for extra visibility since it's often tiny and sparse

-- floors
dat.tile["stone-path"].map_color = {r=.3, g=.3, b=.3, a = full}		-- dark grey
dat.tile.concrete.map_color = {r=.4, g=.4, b=.4, a = full}		-- medium grey
dat.tile["hazard-concrete-left"].map_color = {r=.3, g=.3, b=.1, a = full}		-- dark yellow
if dat.tile["wood-floor"] then dat.tile["wood-floor"].map_color = {r=.5, g=.3, b=.2, a = full} end		-- faded brown

-- miscellaneous 
dat.lamp["small-lamp"].friendly_map_color = {r=1, g=1, b=.2, a = part}			-- vivid yellow lamps
dat.lab.lab.friendly_map_color = {r=.4, g=.7, b=1.0, a = full}		-- labs are light blue
dat["rocket-silo"]["rocket-silo"].friendly_map_color = {r=0, g=0, b=.2, a = full}		-- a dark blue, gaping void to throw infinite resources into :D
dat.radar.radar.friendly_map_color = {r=.0, g=1, b=.2, a = full}		-- light teal, helps them stand out
dat["mining-drill"]["electric-mining-drill"].friendly_map_color = {r=.3, g=.55, b=.35, a = full}		-- sea-foam green
dat["mining-drill"]["burner-mining-drill"].friendly_map_color = {r=.2, g=.35, b=.25, a = full}		-- a bit darker
dat.roboport.roboport.friendly_map_color = {r=.5, g=.3, b=1.0, a = full}	-- violet, to help them stand out
--dat.beacon.beacon.friendly_map_color = {r=.8, g=.4, b=1.0, a = full}	-- pink, likewise
dat.wall["stone-wall"].friendly_map_color = {r=.8, g=.8, b=.8, a = full}		-- bright grey
dat.gate.gate.friendly_map_color = {r=.8, g=.8, b=.8, a = slight}
dat["straight-rail"]["straight-rail"].friendly_map_color = {r=.7, g=.5, b=.4, a = part}	-- faded red-orange on rails, to signify danger
dat["curved-rail"]["curved-rail"].friendly_map_color = {r=.7, g=.5, b=.4, a = part}

-- Ergänzungen von Dani
dat["rail-signal"]["rail-signal"].friendly_map_color = {r=.7, g=.5, b=.4, a = slight}
dat["rail-chain-signal"]["rail-chain-signal"].friendly_map_color = {r=.7, g=.5, b=.4, a = slight}
if dat["constant-combinator"]["placed-train-limit"] then dat["constant-combinator"]["placed-train-limit"].friendly_map_color = {r=.7, g=.5, b=.4, a = slight} end
if dat["constant-combinator"]["placed-train-unlimit"] then dat["constant-combinator"]["placed-train-unlimit"].friendly_map_color = {r=.7, g=.5, b=.4, a = slight} end
dat.beacon.beacon.friendly_map_color = {r=.7, g=.4, b=.7, a = full}	-- Modulstation etwas unauffälliger
local combinators = {r=.4, g=.7, b=1.0, a= part} -- Kombinatoren haben die gleiche Farbe von Laboren, nur etwas transparenter
dat["constant-combinator"]["constant-combinator"].friendly_map_color = combinators
dat["arithmetic-combinator"]["arithmetic-combinator"].friendly_map_color = combinators
dat["decider-combinator"]["decider-combinator"].friendly_map_color = combinators
dat["power-switch"]["power-switch"].friendly_map_color = combinators
if dat.lamp["alert-combinator"] then dat.lamp["alert-combinator"].friendly_map_color = combinators end